.. blohg documentation master file, created by
   sphinx-quickstart on Tue Apr 26 23:45:47 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to blohg's documentation!
=================================

:Author: Rafael Goncalves Martins
:Website: http://blohg.org/
:Source code: http://hg.rafaelmartins.eng.br/blohg/
:Bugs to: blohg@librelist.com
:Version: |release|

Contents:

.. toctree::
   :maxdepth: 3

   about
   install
   new-blog
   write
   deploy

